pub fn parse_ulid(id: &str) -> Result<Ulid, DecodeError>Expand description
Quick helper function to verify that a ULID is valid. We need this because the ULID type does not implement the JsonSchema trait that would allow us to validate the ULID in the request directly. We don’t need to return the ULID itself since Redis just uses the string representation.